@@ -2,13 +2,13 @@ package gurpm::RPMProgressDialog;
 
 #- Copyright (C) 2005 MandrakeSoft SA
 #- Copyright (C) 2005-2010 Mandriva SA
-#- Copyright (C) 2011-2020 Mageia
+#- Copyright (C) 2013 Mageia
 
 # Sharing code from gurpmi2 && Rpmdrake::gurpm
 # Gtk3 only (no ugtk3/mygtk3) as it's used by gurpmi too...
 #
 
-=head1 SYNOPSIS
+=head1 SYNOPSYS
 
 gurpm::RPMProgressDialog is a widget for gurpmi, rpmdrake (drakx already has its own)
 that presents a global progress bar.
@@ -77,7 +77,7 @@ sub new {
     $w->set_border_width(12);
     $w->set_title($w->title);
     $w->signal_connect(destroy => $o_quit) if $o_quit;
-    $w->set_position('center_always');
+    $w->set_position('center');
     $w->set_default_size($progressbar_size, 60);
     # for matchbox window manager during install:
     if (!$o_no_modal) {
@@ -227,8 +227,7 @@ sub invalidate_cancel {
 
 =item invalidate_cancel($self)
 
-Disable the "Cancel" button if any and make it insensitive so that it'll never
-be usable again.
+Disable the "Cancel" button if any.
 
 =cut
 
@@ -391,7 +390,7 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
+Copyright (C) 2011-2013 Mageia
 
 =cut
 
