@@ -1,4 +1,3 @@
-package urpm::bug_report;
 
 use strict;
 use urpm;
@@ -71,6 +70,7 @@ sub copy_requested {
 
 1;
 
+__END__
 
 =back
 
@@ -80,6 +80,4 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
-
 =cut
