@@ -9,6 +9,9 @@ use Cwd;
 use Exporter;
 # perl_checker: require urpm
 
+# help perl_checker:
+sub getcwd { goto &Cwd::getcwd }
+
 our @ISA = 'Exporter';
 our @EXPORT = qw(get_proxy
 	propagate_sync_callback
@@ -537,7 +540,7 @@ sub _curl_action {
 			}
 			#- this checks that download has actually started
 			if ($_ eq "\n"
-			    && !($speed eq 0 && $percent == 100 && index($eta, '--') >= 0) #- work around bug 13685
+			    && !($speed == 0 && $percent == 100 && index($eta, '--') >= 0) #- work around bug 13685
 			) {
 			    propagate_sync_callback($options, 'end', $file);
 			    $file = undef;
@@ -815,7 +818,7 @@ END {
 
 #- get the width of the terminal
 my $wchar = 79;
-if (-t STDOUT) {
+if (-t *STDOUT) {
   eval {
     require Term::ReadKey;
     ($wchar) = Term::ReadKey::GetTerminalSize();
